<?php
/* $Id: danish-iso-8859-1.inc.php,v 2.93 2005/08/18 09:58:59 lem9 Exp $ */
/* Dansk v 2.92 18/8-2005 00:00:00 - overstter AlleyKat kan kontaktes p < phpmyadmin (at) phpbb2.dk > */

$charset = 'iso-8859-1';
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = '.';
$number_decimal_separator = ',';
// forkortelser for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('sn', 'man', 'tir', 'ons', 'tor', 'fre', 'lr');
$month = array('jan', 'feb', 'mar', 'apr', 'maj', 'jun', 'jul', 'aug', 'sep', 'okt', 'nov', 'dec');
// Se http://www.php.net/manual/en/function.strftime.php
// for at definere variablen herunder
$datefmt = '%d/%m %Y kl. %H:%M:%S';
$timespanfmt = '%s dage, %s timer, %s minutter og %s sekunder';

$strAPrimaryKey = 'En primr ngle er blevet tilfjet til %s';
$strAbortedClients = 'Afbrudt';
$strAbsolutePathToDocSqlDir = 'Indtast venligst absolut sti p webserveren til docSQL mappen';
$strAccessDenied = 'Adgang Ngtet';
$strAccessDeniedExplanation = 'phpMyAdmin forsgte at forbinde til MySQL-serveren, og serveren afviste forbindelsen. Du br tjekke host, brugernavn og kodeord i config.inc.php og sikre dig at de svarer til den information du har fet af administratoren af MySQL-serveren.';
$strAction = 'Handling';
$strAddAutoIncrement = 'Tilfj AUTO_INCREMENT vrdi';
$strAddConstraints = 'Tilfj begrnsninger';
$strAddDeleteColumn = 'Tilfj/Slet felt-kolonne';
$strAddDeleteRow = 'Tilfj/Slet kriterie-rkke';
$strAddDropDatabase = 'Tilfj DROP DATABASE';
$strAddFields = 'Tilfj %s felt(er)';
$strAddHeaderComment = 'Tilfj tilpassede kommentarer i headeren (\\n deler linjer)';
$strAddIfNotExists = 'Tilfj IF NOT EXISTS';
$strAddIntoComments = 'Tilfj til kommentarer';
$strAddNewField = 'Tilfj nyt felt';
$strAddPrivilegesOnDb = 'Tilfj privilegier p flgende database';
$strAddPrivilegesOnTbl = 'Tilfj privileges p flgende tabel';
$strAddSearchConditions = 'Tilfj sgekriterier (kroppen af "WHERE" stningen):';
$strAddToIndex = 'Fj til indeks &nbsp;%s&nbsp;kolonne(r)';
$strAddUser = 'Tilfj en ny bruger';
$strAddUserMessage = 'Du har tilfjet en ny bruger.';
$strAddedColumnComment = 'Tilfjet kommentar til kolonne';
$strAddedColumnRelation = 'Tilfjet relation til kolonne';
$strAdministration = 'Administration';
$strAffectedRows = 'Berrte rkker:';
$strAfter = 'Efter %s';
$strAfterInsertBack = 'Retur';
$strAfterInsertNewInsert = 'Indst en ny record';
$strAfterInsertNext = "Redigr nste rkke";
$strAfterInsertSame = 'G tilbage til denne side';
$strAll = 'Alle';
$strAllTableSameWidth = 'vis alle tabeller med samme bredde?';
$strAlterOrderBy = 'Arranger rkkeorden efter';
$strAnIndex = 'Der er tilfjet et indeks til %s';
$strAnalyzeTable = 'Analyser tabel';
$strAnd = 'Og';
$strAndThen = "og s";
$strAny = 'Enhver';
$strAnyHost = 'Enhver vrt';
$strAnyUser = 'Enhver bruger';
$strApproximateCount = 'Kan vre anslet. Se FAQ 3.11';
$strArabic = 'Arabisk';
$strArmenian = 'Armensk';
$strAscending = 'Stigende';
$strAtBeginningOfTable = 'I begyndelsen af tabel';
$strAtEndOfTable = 'I slutningen af tabel';
$strAttr = 'Attributter';
$strAutodetect = 'Fastsl automatisk';
$strAutomaticLayout = 'Automatisk layout';

$strBack = 'Tilbage';
$strBaltic = 'Baltisk';
$strBeginCut = 'BEGYND KLIP';
$strBeginRaw = 'BEGYND R';
$strBinLogEventType = 'Hndelsestype';
$strBinLogInfo = 'Information';
$strBinLogName = 'Lognavn';
$strBinLogOriginalPosition = 'Original position';
$strBinLogPosition = 'Position';
$strBinLogServerId = 'Server ID';
$strBinary = ' Binrt ';
$strBinaryDoNotEdit = ' Binrt - m ikke ndres ';
$strBinaryLog = 'Binr log';
$strBookmarkAllUsers = 'Lad alle brugere f adgang til bogmrket';
$strBookmarkDeleted = 'Bogmrket er fjernet.';
$strBookmarkLabel = 'Mrke';
$strBookmarkOptions = 'Indstillinger for bogmrke';
$strBookmarkQuery = 'SQL-foresprgsel med bogmrke';
$strBookmarkThis = 'Lav bogmrke til denne SQL-foresprgsel';
$strBookmarkView = 'Kun oversigt';
$strBrowse = 'Vis';
$strBrowseForeignValues = 'Bladr i udenlandske vrdier';
$strBufferPool = 'Buffer Pool';
$strBufferPoolActivity = 'Buffer Pool Aktivitet';
$strBufferPoolUsage = 'Buffer Pool Forbrug';
$strBufferReadMisses = 'Read misses';
$strBufferReadMissesInPercent = 'Read misses i %';
$strBufferWriteWaits = 'Write waits';
$strBufferWriteWaitsInPercent = 'Write waits i %';
$strBulgarian = 'Bulgarsk';
$strBusyPages = 'Travle sider';
$strBzError = 'phpMyAdmin kunne ikke komprimere dumpet pga. en delagt Bz2-udvidelse i denne php-version. Det anbefales strkt at stte <code>$cfg[\'BZipDump\']</code>-direktivet i din phpMyAdmin-konfigurationsfil til <code>FALSE</code>. Hvis du vil bruge Bz2-komprimeringsudvidelser, br du opdatere til en nyere php version. Se php bug report %s for detaljer.';
$strBzip = '"bzipped"';

$strCSVOptions = 'CSV-indstillinger';
$strCalendar = 'Kalender';
$strCannotLogin = 'Kan ikke logge ind p MySQL-serveren';
$strCantLoad = 'kan ikke indlse udvidelsen %s,<br />check PHP-konfigurationen!';
$strCantLoadRecodeIconv = 'Kan ikke indlse iconv eller omkode ndvendig udvidelse til tegnst-konvertering, konfigurer php til at tillade brug af disse udvidelser eller sl tegnst-konvertering fra i phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Kan ikke omdbe indeks til PRIMARY!';
$strCantUseRecodeIconv = 'Kan ikke bruge iconv ejheller libiconv eller recode_string funktionen omend udvidelsen ser ud til at vre indlst. Check din php-konfiguration.';
$strCardinality = 'Kardinalitet';
$strCarriage = 'Carriage return: \\r';
$strCaseInsensitive = 'ingen forskel p store/sm bogstaver';
$strCaseSensitive = 'forskel p store/sm bogstaver';
$strCentralEuropean = 'Centraleuropisk';
$strChange = 'ndre';
$strChangeCopyMode = 'Opret en bruger med samme privilegier og ...';
$strChangeCopyModeCopy = '... behold den gamle.';
$strChangeCopyModeDeleteAndReload = ' ... slet den gamle fra brugertabellerne og genindls privilegierne efterflgende.';
$strChangeCopyModeJustDelete = ' ... slet den gamle fra brugertabellerne.';
$strChangeCopyModeRevoke = ' ... tilbagekald alle aktive privilegier fra den gamle og slet den efterflgende.';
$strChangeCopyUser = 'Ret Login-information / Kopir bruger';
$strChangeDisplay = 'Vlg felt der skal vises';
$strChangePassword = 'ndre kodeord';
$strCharset = 'Tegnst';
$strCharsetOfFile = 'Tegnst for filen:';
$strCharsets = 'Tegnst';
$strCharsetsAndCollations = 'Tegnst og kollationer (Collations)';
$strCheckAll = 'Afmrk alt';
$strCheckOverhead = 'Check tabeller der har overhead';
$strCheckPrivs = 'Check Privilegier';
$strCheckPrivsLong = 'Check privilegier for database &quot;%s&quot;.';
$strCheckTable = 'Tjek tabel';
$strChoosePage = 'Vlg en side der skal redigeres';
$strColComFeat = 'Viser kolonne-kommentarer';
$strCollation = 'Kollation (Collation)';
$strColumnNames = 'Kolonne navne';
$strColumnPrivileges = 'Kolonne-specifikke privilegier';
$strCommand = 'Kommando';
$strComments = 'Kommentarer';
$strCommentsForTable = 'COMMENTS FOR TABLE (tabel-kommentarer)';
$strCompatibleHashing = 'MySQL&nbsp;4.0 kompatibel';
$strCompleteInserts = 'Lav komplette inserts';
$strCompression = 'Komprimering';
$strConfigFileError = 'phpMyAdmin kunne ikke lse din konfigurationsfil!<br />Dette kan ske hvis php finder en parser-fejl i den, eller php kan ikke finde filen.<br />Kald konfigurationsfilen direkte fra nedenstende link og ls de(n) phpfejlmeddelse(r) du fr. I de fleste tilflde mangler der et anfrselstegn eller et semikolon et sted.<br />Hvis du fr en blank side, er alt i orden.';
$strConfigureTableCoord = 'Konfigurr venligst koordinaterne for tabel %s';
$strConnectionError = 'Kan ikke forbinde: ugyldige indstillinger.';
$strConnections = 'Forbindelser';
$strConstraintsForDumped = 'Begrnsninger for dumpede tabeller';
$strConstraintsForTable = 'Begrnsninger for tabel';
$strCookiesRequired = 'Herefter skal cookies vre sat til.';
$strCopy = 'Kopi';
$strCopyDatabaseOK = 'Database %s er blevet kopieret til %s';
$strCopyTable = 'Kopier tabel til (database<b>.</b>tabel):';
$strCopyTableOK = 'Tabellen %s er nu kopieret til: %s.';
$strCopyTableSameNames = 'Kan ikke kopiere tabellen til den samme!';
$strCouldNotKill = 'phpMyAdmin kunne ikke drbe trden %s. Den er sandsynligvis allerede lukket.';
$strCreate = 'Opret';
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE fr kopiering';
$strCreateIndex = 'Dan et indeks p&nbsp;%s&nbsp;kolonner';
$strCreateIndexTopic = 'Lav et nyt indeks';
$strCreateNewDatabase = 'Opret ny database';
$strCreateNewTable = 'Opret ny tabel i database %s';
$strCreatePage = 'Opret en ny side';
$strCreatePdfFeat = 'Oprettelse af PDFer';
$strCreationDates = 'Oprettet/Opdateret/Check datoer';
$strCriteria = 'Kriterier';
$strCroatian = 'Kroatisk';
$strCyrillic = 'Kyrillisk';
$strCzech = 'Tjekkisk';
$strCzechSlovak = 'Tjekkisk-Slovakisk';

$strDBComment = 'Databasekommentar: ';
$strDBCopy = 'Kopir database til';
$strDBGContext = 'Sammenhng';
$strDBGContextID = 'Sammenhng-ID';
$strDBGHits = 'Hits';
$strDBGLine = 'Linje';
$strDBGMaxTimeMs = 'Max tid, ms';
$strDBGMinTimeMs = 'Min tid, ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'Tid/Hit, ms';
$strDBGTotalTimeMs = 'Total tid, ms';
$strDBRename = 'Omdb database til';
$strDanish = 'Dansk';
$strData = 'Data';
$strDataDict = 'Data Dictionary';
$strDataOnly = 'Kun data';
$strDataPages = 'Sider der indeholder data';
$strDatabase = 'Database';
$strDatabaseEmpty = 'Databasenavnet er tomt!';
$strDatabaseExportOptions = 'Database eksportindstillinger';
$strDatabaseHasBeenDropped = 'Database %s er slettet.';
$strDatabaseNoTable = 'Denne database indeholder ikke nogen tabel!';
$strDatabases = 'Databaser';
$strDatabasesDropped = '%s databaser er blevet droppet korrekt.';
$strDatabasesStats = 'Databasestatistik';
$strDatabasesStatsDisable = 'Sl Statistikker fra';
$strDatabasesStatsEnable = 'Sl Statistikker til';
$strDatabasesStatsHeavyTraffic = 'Bemrk: At sl databasestatistikkerne til her kan forrsage tung trafik mellem webserveren og MySQL-serveren.';
$strDbPrivileges = 'Database-specifikke privilegier';
$strDbSpecific = 'database-specifik';
$strDefault = 'Standardvrdi';
$strDefaultEngine = '%s er standard datalageret p denne MySQL-server.';
$strDefaultValueHelp = 'For standardvrdier, indtast venligst kun en enkelt vrdi, uden backslash escaping eller quotes, ud fra flgende format: a';
$strDefragment = 'Defragmentr tabel';
$strDelOld = 'Nuvrende side har referencer til tabeller der ikke lngere eksisterer. Vil du slette disse referencer?';
$strDelayedInserts = 'Brug forsinkede indsttelser';
$strDelete = 'Slet';
$strDeleteAndFlush = 'Slet brugerne og genindls privilegier bagefter.';
$strDeleteAndFlushDescr = 'Dette er den sikreste metode, men genindlsning af privilegierne kan tage noget tid.';
$strDeleted = 'Rkken er slettet!';
$strDeletedRows = 'Slettede rkker:';
$strDeleting = 'Sletter %s';
$strDescending = 'Faldende';
$strDescription = 'Beskrivelse';
$strDictionary = 'ordbog';
$strDirtyPages = 'Beskidte sider';
$strDisableForeignChecks = 'Sl fremmedngle-checks fra';
$strDisabled = 'Slet fra';
$strDisplayFeat = 'Vis muligheder';
$strDisplayOrder = 'Rkkeflge af visning:';
$strDisplayPDF = 'Vis PDF skematik';
$strDoAQuery = 'Kr en foresprgsel p felter (jokertegn: "%")';
$strDoYouReally = 'Er du sikker p at du vil ';
$strDocu = 'Dokumentation';
$strDrop = 'Slet';
$strDropDatabaseStrongWarning = 'Du er ved at DESTRUERE en komplet database!';
$strDropSelectedDatabases = 'Drop (slet) valgte Databaser';
$strDropUsersDb = 'Drop databaser der har samme navne som brugernes.';
$strDumpSaved = 'Dump er blevet gemt i filen %s.';
$strDumpXRows = 'Dump %s rkker startende med rkke %s.';
$strDumpingData = 'Data dump for tabellen';
$strDynamic = 'dynamisk';

$strEdit = 'Ret';
$strEditPDFPages = 'Redigr PDF-sider';
$strEditPrivileges = 'Ret privilegier';
$strEffective = 'Effektiv';
$strEmpty = 'Tm';
$strEmptyResultSet = 'MySQL returnerede ingen data (fx ingen rkker).';
$strEnabled = 'Slet til';
$strEncloseInTransaction = 'Inkludr eksport i en transaktion';
$strEnd = 'Slut';
$strEndCut = 'SLUT KLIP';
$strEndRaw = 'SLUT R';
$strEngineAvailable = '%s er tilgngelig p denne MySQL-server.';
$strEngineDisabled = '%s er slet fra p denne MySQL-server.';
$strEngineUnsupported = 'Denne MySQL-server understtter ikke %s datalager.';
$strEngines = 'Lagre';
$strEnglish = 'Engelsk';
$strEnglishPrivileges = ' NB: Navne p MySQL privilegier er p engelsk ';
$strError = 'Fejl';
$strEscapeWildcards = 'Jokertegn _ og % skal vre escaped med en \ foran for at bruge dem bogstaveligt';
$strEstonian = 'Estisk';
$strExcelEdition = 'Excel-udgave';
$strExcelOptions = 'Excel-indstillinger';
$strExecuteBookmarked = 'Udfr foresprgsel iflg. bogmrke';
$strExplain = 'Forklar SQL';
$strExport = 'Eksport';
$strExtendedInserts = 'Udvidede inserts';
$strExtra = 'Ekstra';

$strFailedAttempts = 'Mislykkede forsg';
$strField = 'Feltnavn';
$strFieldHasBeenDropped = 'Felt %s er slettet';
$strFields = 'Felter';
$strFieldsEmpty = ' Felttallet har ingen vrdi! ';
$strFieldsEnclosedBy = 'Felter indrammet med';
$strFieldsEscapedBy = 'Felter escaped med';
$strFieldsTerminatedBy = 'Felter afsluttet med';
$strFileAlreadyExists = 'Filen %s findes allerede p serveren, ndr filnavn eller tillad at der overskrives.';
$strFileCouldNotBeRead = 'Filen kunne ikke lses';
$strFileNameTemplate = 'Skabelon for filnavn';
$strFileNameTemplateHelp = 'Brug __DB__ for databasenavn, __TABLE__ for tabelnavn og %senhver strftime%s sammenstning for tidsspecifikation, extension (filefternavn) tilfjes automagisk. Al anden tekst bevares.';
$strFileNameTemplateRemember = 'husk skabelonen';
$strFixed = 'ordnet';
$strFlushPrivilegesNote = 'Bemrk: phpMyAdmin henter brugernes privilegier direkte fra MySQL\'s privilegietabeller. Indholdet af disse tabeller kan vre forskelligt fra privilegierne serveren bruger hvis der er lavet manuelle ndringer i den. Hvis det er tilfldet, br du %sgenindlse privilegierne%s fr du fortstter.';
$strFlushTable = 'Flush tabellen ("FLUSH")';
$strFormEmpty = 'Ingen vrdi i formularen !';
$strFormat = 'Format';
$strFreePages = 'Frie sider';
$strFullText = 'Komplette tekster';
$strFunction = 'Funktion';

$strGenBy = 'Genereret af';
$strGenTime = 'Genereringstid';
$strGeneralRelationFeat = 'Generelle relationsmuligheder';
$strGenerate = 'Generr';
$strGeneratePassword = 'Generr Kodeord';
$strGeorgian = 'Georgisk';
$strGerman = 'Tysk';
$strGlobal = 'global';
$strGlobalPrivileges = 'Globale privilegier';
$strGlobalValue = 'Global vrdi';
$strGo = 'Udfr';
$strGrantOption = 'Tildel';
$strGreek = 'Grsk';
$strGzip = '"gzipped"';

$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Microsoft Excel 2000 eksportindstillinger';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Microsoft Word 2000 eksportindstillinger';
$strHasBeenAltered = 'er ndret.';
$strHasBeenCreated = 'er oprettet.';
$strHaveToShow = 'Du skal vlge mindst en kolonne der skal vises';
$strHebrew = 'Hebrisk';
$strHexForBinary = 'Brug hexadecimal til binre felter';
$strHome = 'Hjem';
$strHomepageOfficial = 'Officiel phpMyAdmin hjemmeside ';
$strHost = 'Vrt';
$strHostEmpty = 'Der er intet vrtsnavn!';
$strHungarian = 'Ungarsk';

$strIcelandic = 'Islandsk';
$strId = 'ID';
$strIdxFulltext = 'Fuldtekst';
$strIfYouWish = 'Hvis du kun nsker at importere nogle af tabellens kolonner, angives de med en kommasepareret felt liste.';
$strIgnore = 'Ignorer';
$strIgnoreInserts = 'Brug ignorr inserts';
$strIgnoringFile = 'Ignorerer fil %s';
$strImportDocSQL = 'Importer docSQL Filer';
$strImportFiles = 'Importr filer';
$strImportFinished = 'Import frdig';
$strInUse = 'i brug';
$strIndex = 'Indeks';
$strIndexHasBeenDropped = 'Indeks %s er blevet slettet';
$strIndexName = 'Indeksnavn&nbsp;:';
$strIndexType = 'Indekstype&nbsp;:';
$strIndexWarningMultiple = 'Mere end en %s ngle blev skabt for kolonne `%s`';
$strIndexWarningPrimary = 'PRIMARY og INDEX ngler burde ikke begge vre sat for kolonne `%s`';
$strIndexWarningTable = 'Problemer med indeksene p tabel `%s`';
$strIndexWarningUnique = 'UNIQUE og INDEX ngler burde ikke begge vre sat for kolonne `%s`';
$strIndexes = 'Indeks';
$strInnoDBAutoextendIncrement = 'Autoextend forgelse';
$strInnoDBAutoextendIncrementDesc = ' Strrelsen p den udvidelse der vil forekomme, nr pladsen i en autoudvidende tabel udvides fordi den lber fuld.';
$strInnoDBBufferPoolSize = 'Buffer pool strrelse';
$strInnoDBBufferPoolSizeDesc = 'Strrelse p memorybufferen InnoDB bruger til at cache data og indeks p dets tabeller.';
$strInnoDBDataFilePath = 'Datafiler';
$strInnoDBDataHomeDir = 'Data hovedmappe';
$strInnoDBDataHomeDirDesc = 'Den flles del af stien til mappen med alle InnoDB datafiler.';
$strInnoDBPages = 'sider';
$strInnodbStat = 'InnoDB status';
$strInsecureMySQL = 'Din konfigurationsfil indeholder indstillinger (root og uden kodeord) som svarer til en standard MySQL priviligeret brugerkonto. Din MySQL server krer med denne standardindstilling, <u>er ben for indtrngen</u>, og du br virkelig gre noget ved dette sikkerhedshul.';
$strInsert = 'Indst';
$strInsertAsNewRow = 'Indst som ny rkke';
$strInsertBookmarkTitle = 'Indst venligst bogmrke-titel';
$strInsertNewRow = 'Indst ny rkke';
$strInsertTextfiles = 'Importer tekstfil til tabellen';
$strInsertedRowId = 'Indsat rkke-id:';
$strInsertedRows = 'Indsatte rkker:';
$strInstructions = 'Instruktioner';
$strInternalNotNecessary = '* En intern relation er ikke ndvendig nr den ogs eksisterer i InnoDB.';
$strInternalRelations = 'Interne relationer';
$strInvalidColumnCount = 'Kolonnetlling skal vre strre end nul.';
$strInvalidFieldAddCount = 'Du skal tilfje mindst t felt.';
$strInvalidFieldCount = 'Tabellen skal indeholde mindst t felt.';
$strInvalidRowNumber = '%d er ikke gyldigt rkkenummer.';

$strJapanese = 'Japansk';
$strJumpToDB = 'Hop til database &quot;%s&quot;.';
$strJustDelete = 'Bare slet brugerne fra privilegietabellerne.';
$strJustDeleteDescr = 'De &quot;slettede&quot; brugere kan stadig tilg serveren som de plejer indtil privilegierne genindlses.';

$strKeepPass = 'Kodeord m ikke ndres';
$strKeyname = 'Nglenavn';
$strKill = 'Kill';
$strKorean = 'Koreansk';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX indstillinger';
$strLandscape = 'Liggende';
$strLatchedPages = 'Eksklusivt lste (latched) sider';
$strLatexCaption = 'Tabeloverskrift';
$strLatexContent = 'Indhold af tabel __TABLE__';
$strLatexContinued = '(fortsttes)';
$strLatexContinuedCaption = 'Fortsat tabeloverskrift';
$strLatexIncludeCaption = 'Inkluder tabeloverskrift';
$strLatexLabel = 'Mrke ngle';
$strLatexStructure = 'Struktur for tabel __TABLE__';
$strLatvian = 'Lettisk';
$strLengthSet = 'Lngde/Vrdi*';
$strLimitNumRows = 'poster pr. side';
$strLineFeed = 'Linefeed: \\n';
$strLinesTerminatedBy = 'Linjer afsluttet med';
$strLinkNotFound = 'Link ikke fundet';
$strLinksTo = 'Linker til';
$strLithuanian = 'Litauisk';
$strLoadExplanation = 'Den bedste metode er markeret som standard, men du kan ndre den hvis det svigter.';
$strLoadMethod = 'LOAD metode';
$strLocalhost = 'Lokal';
$strLocationTextfile = 'Tekstfilens placering';
$strLogPassword = 'Kodeord:';
$strLogServer = 'Server';
$strLogUsername = 'Brugernavn:';
$strLogin = 'Login';
$strLoginInformation = 'Login-information';
$strLogout = 'Log af';
$strLongOperation = 'Denne operation kan tage lang tid. Fortst alligevel?';

$strMIMETypesForTable = 'MIME TYPES FOR TABLE (MIME-typer for tabellen)';
$strMIME_MIMEtype = 'MIME-type';
$strMIME_available_mime = 'Tilgngelige MIME-typer';
$strMIME_available_transform = 'Tilgngelige transformationer';
$strMIME_description = 'Beskrivelse';
$strMIME_nodescription = 'Der er ingen beskrivelse af denne transformation.<br />Sprg venligst forfatteren, hvad %s gr.';
$strMIME_transformation = 'Browser transformation';
$strMIME_transformation_note = 'For en liste over mulige transformationsindstillinger og deres MIME-type transformationer, klik p %stransformationsbeskrivelser%s';
$strMIME_transformation_options = 'Transformationsindstillinger';
$strMIME_transformation_options_note = 'Indtast vrdier for transformationsindstillinger ud fra flgende format: \'a\',\'b\',\'c\'...<br />Skulle du f brug for at indstte en backslash ("\") eller en apostrof ("\'") i vrdierne, backslash det (for eksempel \'\\\\xyz\' eller \'a\\\'b\').';
$strMIME_without = 'MIME-typer skrevet med kursiv har ikke en separat transformationsfunktion';
$strMaximumSize = 'Maksimum strrelse: %s%s';
$strMbExtensionMissing = "PHP-udvidelsen mbstring blev ikke fundet og du ser ud til at bruge et multibyte tegnst. Uden mbstring-udvidelsen er phpMyAdmin ude af stand til at opdele  strenge korrekt og dette kan forrsage uventede resultater.";
$strMbOverloadWarning = "Du har mbstring.func_overload slet til i din PHP-konfiguration. Denne indstilling er ikke kompatibel med phpMyAdmin og kan forrsage delggelse af nogle data!";
$strModifications = 'Rettelserne er gemt!';
$strModify = 'Ret';
$strModifyIndexTopic = 'ndring af et indeks';
$strMoreStatusVars = 'Flere statusvariabler';
$strMoveTable = 'Flyt tabel til (database<b>.</b>tabel):';
$strMoveTableOK = 'Tabel %s er flyttet til %s.';
$strMoveTableSameNames = 'Kan ikke flytte tabellen til den samme!';
$strMultilingual = 'flersproget';
$strMustSelectFile = 'Vlg en fil du vil indstte.';
$strMyISAMDataPointerSize = 'Data pointer strrelse';
$strMyISAMDataPointerSizeDesc = 'Standard pointerstrrelse i bytes, til brug ved CREATE TABLE for MyISAM tabeller nr der ikke er specificeret nogen MAX_ROWS indstilling.';
$strMyISAMMaxExtraSortFileSize = 'Maksimal strrelse for midlertidige filer ved oprettelse af indeks';
$strMyISAMMaxExtraSortFileSizeDesc = 'Hvis den midlertidige fil der bruges til hurtig MyISAM indeks-oprettelse ville vre strre end ved brug af key cache med strrelsen angivet her, foretrk key cache-metoden.';
$strMyISAMMaxSortFileSize = 'Maksimal strrelse for midlertidige sorteringsfiler';
$strMyISAMMaxSortFileSizeDesc = 'Maksimal strrelse for den midlertidige fil MySQL har lov til at bruge under genetablering af et MyISAM indeks (under REPAIR TABLE, ALTER TABLE, eller LOAD DATA INFILE).';
$strMyISAMRecoverOptions = 'Automatisk genopretnings-modus';
$strMyISAMRecoverOptionsDesc = 'Modus for automatisk genetablering af crashede MyISAM tabeller, som sat via --myisam-recover server opstartsindstillingen.';
$strMyISAMRepairThreads = 'Reparr trde';
$strMyISAMRepairThreadsDesc = 'Hvis denne vrdi er strre end 1, oprettes MyISAM tabel-indeks parallelt (hvert indeks i dets egen trd) under Reparation ved sortering-processen.';
$strMyISAMSortBufferSize = 'Sorterings-bufferstrrelse';
$strMyISAMSortBufferSizeDesc = 'Bufferen der allokeres ved sortering af MyISAM indeks under en REPAIR TABLE eller nr indeks oprettes med CREATE INDEX eller ALTER TABLE.';
$strMySQLCharset = 'MySQL Tegnst';
$strMySQLConnectionCollation = 'MySQL forbindelses-sammenkring';
$strMySQLReloaded = 'MySQL genstartet.';
$strMySQLSaid = 'MySQL returnerede: ';
$strMySQLServerProcess = 'MySQL %pma_s1% krer p %pma_s2% som %pma_s3%';
$strMySQLShowProcess = 'Vis trde';
$strMySQLShowStatus = 'Vis MySQL runtime-information';
$strMySQLShowVars = 'Vis MySQL systemvariabler';

$strName = 'Navn';
$strNeedPrimaryKey = 'Du burde definere en primr ngle for denne tabel.';
$strNext = 'Nste';
$strNo = 'Nej';
$strNoActivity = 'Ingen aktivitet i de seneste %s sekunder eller mere, log venligst ind igen';
$strNoDatabases = 'Ingen databaser';
$strNoDatabasesSelected = 'Ingen databaser valgt.';
$strNoDescription = 'ingen beskrivelse';
$strNoDetailsForEngine = 'Der er ingen detaljerede statusinformationer tilgngelige for dette datalager.';
$strNoDropDatabases = '"DROP DATABASE" erklringer kan ikke bruges.';
$strNoExplain = 'Spring over Forklar SQL';
$strNoFrames = 'phpMyAdmin er mere brugervenlig med en browser, der kan klare <b>frames</b>.';
$strNoIndex = 'Intet indeks defineret!';
$strNoIndexPartsDefined = 'Ingen dele af indeks er definerede!';
$strNoModification = 'Ingen ndring';
$strNoOptions = 'Dette format har ingen indstillinger';
$strNoPassword = 'Intet kodeord';
$strNoPermission = 'Webserveren har ikke tilladelse til at gemme filen %s.';
$strNoPhp = 'uden PHP-kode';
$strNoPrivileges = 'Ingen privilegier';
$strNoQuery = 'Ingen SQL foresprgsel!';
$strNoRights = 'Du har ikke tilstrkkelige rettigheder til at vre her!';
$strNoRowsSelected = 'Ingen rkker valgt';
$strNoSpace = 'Utilstrkkeligt plads til at gemme filen %s.';
$strNoTablesFound = 'Ingen tabeller fundet i databasen.';
$strNoThemeSupport = 'Ingen tema/layout-understttelse, tjek venligst din konfiguration og/eller dine temaer i mappen %s.';
$strNoUsersFound = 'Ingen bruger(e) fundet.';
$strNoValidateSQL = 'Spring over Validr SQL';
$strNone = 'Intet';
$strNotNumber = 'Dette er ikke et tal!';
$strNotOK = 'ikke OK';
$strNotSet = 'Tabel <b>%s</b> findes ikke eller er ikke sat i %s';
$strNull = 'Nulvrdi';
$strNumSearchResultsInTable = '%s hit(s) i tabel <i>%s</i>';
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> hit(s)';
$strNumTables = 'Tabeller';
$strNumberOfFields = 'Antal felter';

$strOK = 'OK';
$strOftenQuotation = 'Ofte anfrselstegn. OPTIONALLY betyder at kun char og varchar felter er omsluttet med det valgte "tekstkvalifikator"-tegn.'; //skal muligvis ndres
$strOperations = 'Operationer';
$strOperator = 'Operatr';
$strOptimizeTable = 'Optimer tabel';
$strOptionalControls = 'Valgfrit. Kontrollerer hvordan specialtegn skrives eller lses.';
$strOptionally = 'OPTIONALLY (alternativt)';
$strOr = 'Eller';
$strOverhead = 'Overhead';
$strOverwriteExisting = 'Overskriv eksisterende fil(er)';

$strPHP40203 = 'Du bruger PHP 4.2.3, som har en alvorlig fejl med multi-byte strenge (mbstring). Se PHP bug report 19404. Denne version af PHP kan ikke anbefales at bruge med phpMyAdmin.';
$strPHPVersion = 'PHP version';
$strPageNumber = 'Side nummer:';
$strPagesToBeFlushed = 'Sider der str til at blive tmt';
$strPaperSize = 'Papirstrrelse';
$strPartialText = 'Delvise tekster';
$strPassword = 'Kodeord';
$strPasswordChanged = 'Kodeordet for %s blev korrekt udskiftet.';
$strPasswordEmpty = 'Der er ikke angivet noget kodeord!';
$strPasswordHashing = 'Kodeord Hashing'; // may be better
$strPasswordNotSame = 'De to kodeord er ikke ens!';
$strPdfDbSchema = 'Skematik for databasen "%s" - Side %s';
$strPdfInvalidTblName = 'Tabellen "%s" findes ikke!';
$strPdfNoTables = 'Ingen tabeller';
$strPerHour = 'pr. time';
$strPerMinute = 'pr. minut';
$strPerSecond = 'pr. sekund';
$strPersian = 'Persisk';
$strPhoneBook = 'telefonbog';
$strPhp = 'Fremstil PHP-kode';
$strPmaDocumentation = 'phpMyAdmin dokumentation';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> direktivet SKAL vre sat i konfigurationsfilen!';
$strPolish = 'Polsk';
$strPortrait = 'Stende';
$strPos1 = 'Start';
$strPrevious = 'Forrige';
$strPrimary = 'Primr';
$strPrimaryKeyHasBeenDropped = 'Primrnglen er slettet';
$strPrimaryKeyName = 'Navnet p primrnglen skal vre... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>skal</b> vre navnet p og <b>kun p</b> en primr ngle!)';
$strPrint = 'Print';
$strPrintView = 'Vis (udskriftvenlig)';
$strPrintViewFull = 'Udskrift-visning (med fulde tekster)';
$strPrivDescAllPrivileges = 'Inkluderer alle privilegier pnr GRANT.';
$strPrivDescAlter = 'Tillader ndring af strukturen p eksisterende tabeller.';
$strPrivDescAlterDb = 'Tillader ndring af strukturen p eksisterende tabeller svel som ndring af standard tegnst og kollation af databaser.';
$strPrivDescAlterRoutine = 'Tillader ndring og sletning af gemte rutiner.';
$strPrivDescCreateDb = 'Tillader oprettelse af nye databaser og tabeller.';
$strPrivDescCreateRoutine = 'Tillader oprettelse af gemte rutiner.';
$strPrivDescCreateTbl = 'Tillader oprettelse af nye tabeller.';
$strPrivDescCreateTmpTable = 'Tillader oprettelse af midlertidige tabeller.';
$strPrivDescCreateUser = 'Tillader oprettelse, sletning og omdbning af brugerkonti.';
$strPrivDescCreateView = 'Tillader oprettelse af nye Allows creating new views.';
$strPrivDescDelete = 'Tillader sletning af data.';
$strPrivDescDropDb = 'Tillader at droppe databaser og tabeller.';
$strPrivDescDropTbl = 'Tillader at droppe tabeller.';
$strPrivDescExecute = 'Tillader krsel af gemte procedurer; Har ingen effekt i denne MySQL-version.';
$strPrivDescExecute5 = 'Tillader udfrelse af gemte rutiner.';
$strPrivDescFile = 'Tillader import af data fra og eksport af data til filer.';
$strPrivDescGrant = 'Tillader oprettelse af brugere og privilegier uden at genindlse privilegie-tabellerne.';
$strPrivDescIndex = 'Tillader at skabe og droppe indeks.';
$strPrivDescInsert = 'Tillader indsttelse og erstatning af data.';
$strPrivDescLockTables = 'Tillader lsning af tabeller for nuvrende trd.';
$strPrivDescMaxConnections = 'Begrnser antallet af nye forbindelser brugeren m bne pr. time.';
$strPrivDescMaxQuestions = 'Begrnser antallet af foresprgsler brugeren m sende til serveren pr. time.';
$strPrivDescMaxUpdates = 'Begrnser antallet af kommandoer som ndrer enhver tabel eller database brugeren m udfre pr. time.';
$strPrivDescProcess3 = 'Tillader at drbe andre brugeres processer.';
$strPrivDescProcess4 = 'Tillader at se komplette foresprgsler i proceslisten.';
$strPrivDescReferences = 'Har ingen effekt i denne MySQL version.';
$strPrivDescReload = 'Tillader genindlsning af serverindstillinger og tmning af caches.';
$strPrivDescReplClient = 'Giver brugeren rettigheder til at sprge hvor Slaves / Masters er.';
$strPrivDescReplSlave = 'Ndvendigt for replikationsslaverne.';
$strPrivDescSelect = 'Tillader lsning af data.';
$strPrivDescShowDb = 'Giver adgang til den fuldstndige liste over databaser.';
$strPrivDescShowView = 'Tillader udfrelse af SHOW CREATE VIEW foresprgsler.';
$strPrivDescShutdown = 'Tillader nedlukning af serveren.';
$strPrivDescSuper = 'Tillader forbindelse, selv hvis maksimalt antal forbindelser er net; Ndvendigt for de fleste administrative operationer som indstilling af globale variabler eller for at drbe andre brugeres trde.';
$strPrivDescUpdate = 'Tillader ndring af data.';
$strPrivDescUsage = 'Ingen privilegier.';
$strPrivileges = 'Privilegier';
$strPrivilegesReloaded = 'Privilegierne blev korrekt genindlst.';
$strProcesslist = 'Procesliste';
$strPutColNames = 'Indst feltnavne i frste rkke';

$strQBE = 'Foresp. via eks.';
$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQueryFrame = 'Foresp. vindue';
$strQueryOnDb = 'SQL-foresprgsel til database <b>%s</b>:';
$strQuerySQLHistory = 'SQL-historik';
$strQueryStatistics = '<b>Foresprgselsstatistikker</b>: Siden opstarten er der blevet sendt %s foresprgsler til serveren.';
$strQueryTime = 'Foreprgsel tog %01.4f sek';
$strQueryType = 'Foresprgselstype';
$strQueryWindowLock = 'Overskriv ikke denne foresprgsel fra udenfor vinduet';

$strReType = 'Skriv igen';
$strReadRequests = 'Read-foresprgsler';
$strReceived = 'Modtaget';
$strRecords = 'Poster';
$strReferentialIntegrity = 'Check reference-integriteten';
$strRefresh = 'Opdatr';
$strRelationNotWorking = 'De ekstra features for at arbejde med linkede tabeller er deaktiveret. For at se hvorfor, klik %sher%s.';
$strRelationView = 'Se Relationer';
$strRelationalSchema = 'Relationel skematik';
$strRelations = 'Relationer';
$strRelationsForTable = 'RELATIONS FOR TABLE (Relationer for tabellen)';
$strReloadFailed = 'Genstart af MySQL fejlede.';
$strReloadMySQL = 'Genstart MySQL';
$strReloadingThePrivileges = 'Genindls privilegierne';
$strRemoveSelectedUsers = 'Fjern valgte brugere';
$strRenameDatabaseOK = 'Database %s er blevet omdbt til %s';
$strRenameTable = 'Omdb tabel til';
$strRenameTableOK = 'Tabellen %s er nu omdbt til %s';
$strRepairTable = 'Reparer tabel';
$strReplace = 'Erstat';
$strReplaceNULLBy = 'Erstat NULL med';
$strReplaceTable = 'Erstat data i tabellen med filens data';
$strReset = 'Nulstil';
$strResourceLimits = 'Ressourcebegrnsninger';
$strRevoke = 'Tilbagekald';
$strRevokeAndDelete = 'Tilbagekald alle aktive privileiger fra brugerne og slet dem efterflgende.';
$strRevokeAndDeleteDescr = 'Bruger(e) vil fortsat have USAGE-privilegiet indtil privilegierne genindlses.';
$strRevokeMessage = 'Du har tilbagekaldt privilegierne for %s';
$strRomanian = 'Rumnsk';
$strRoutines = 'Rutiner';
$strRowLength = 'Rkkelngde';
$strRowSize = ' Rkkestrrelse ';
$strRows = 'Rkker';
$strRowsFrom = 'rkker startende fra post #';
$strRowsModeFlippedHorizontal = 'horisontalt (roterede overskrifter)';
$strRowsModeHorizontal = 'vandret';
$strRowsModeOptions = '%s og gentag overskrifter efter %s celler';
$strRowsModeVertical = 'lodret';
$strRowsStatistic = 'Rkke-statistik';
$strRunQuery = 'Send foresprgsel';
$strRunSQLQuery = 'Kr SQL-forsprgsel(er) p database %s';
$strRunning = 'krer p %s';
$strRussian = 'Russisk';

$strSQL = 'SQL';
$strSQLExportCompatibility = "SQL eksport-kompatibilitet";
$strSQLExportType = 'Eksporttype';
$strSQLOptions = 'SQL-indstillinger';
$strSQLParserBugMessage = 'Det er muligt at du har fundet en fejl i SQL-parseren. Undersg venligst din foresprgsel nje, og check at anfrselstegn er rigtige og ikke giver konflikter. Andre fejlrsager kan vre at du uploader en fil med binr udenfor et lukket tekstomrde. Du kan ogs prve din foresprgsel i MySQL kommandolinje-interfacet. MySQL-serverens fejlmelding der flger herunder, hvis der er nogen, kan ogs hjlpe dig med at finde problemet. Hvis du stadig har probemer eller hvis parseren fejler hvor kommandolinjeinterfacet lykkes, reducer din SQL-foresprgselsinput til den ene foresprgsel der forrsager problemet, og indsend en fejlrapport med datablokken i KLIP-sektionen herunder:';
$strSQLParserUserError = 'Der ser ud til at vre en fejl i din SQL-foresprgsel. MySQL-serverens fejlmelding der flger herunder, hvis der er nogen, kan ogs hjlpe dig med at finde problemet.';
$strSQLQuery = 'SQL-foresprgsel';
$strSQLResult = 'SQL-resultat';
$strSQPBugInvalidIdentifer = 'Ugyldig identifikator';
$strSQPBugUnclosedQuote = 'Ikke-lukket quote';
$strSQPBugUnknownPunctuation = 'Ukendt tegnstnings-streng';
$strSave = 'Gem';
$strSaveOnServer = 'Gem p serveren i mappen %s ';
$strScaleFactorSmall = 'Skaleringsfaktoren er for lille til at tilpasse skematikken til en side';
$strSearch = 'Sg';
$strSearchFormTitle = 'Sg i databasen';
$strSearchInTables = 'Indeni tabel(ler):';
$strSearchNeedle = 'Ord eller vrdi(er) (jokertegn: "%"):';
$strSearchOption1 = 'mindst et af ordene';
$strSearchOption2 = 'alle ordene';
$strSearchOption3 = 'den njagtige stning';
$strSearchOption4 = 'som regulrt udtryk';
$strSearchResultsFor = 'Sgeresultater for "<i>%s</i>" %s:';
$strSearchType = 'Find:';
$strSecretRequired = 'Konfigurationsfilen skal nu bruge et hemmeligt kodeord (blowfish_secret).';
$strSelectADb = 'Vlg en database';
$strSelectAll = 'Vlg alle';
$strSelectBinaryLog = 'Vlg binrlog til gennemsyn';
$strSelectFields = 'Vlg mindst eet felt:';
$strSelectNumRows = 'i foresprgsel';
$strSelectTables = 'Vlg Tabeller';
$strSend = 'Send (download)';
$strSent = 'Sendt';
$strServer = 'Server';
$strServerChoice = 'Server valg';
$strServerNotResponding = 'Serveren svarer ikke';
$strServerStatus = 'Runtime-information';
$strServerStatusUptime = 'Denne MySQL-server har krt i %s. Den startede op den %s.';
$strServerTabProcesslist = 'Processer';
$strServerTabVariables = 'Variabler';
$strServerTrafficNotes = '<b>Servertrafik</b>: Disse tabeller viser netvrkstrafik-statistikkerne for denne MySQL-server siden dens opstart.';
$strServerVars = 'Server-variabler og indstillinger';
$strServerVersion = 'Serverversion';
$strSessionValue = 'Sessionsvrdi';
$strSetEnumVal = 'Hvis et felt er af typen "enum" eller "set", skal vrdierne angives p formen: \'a\',\'b\',\'c\'...<br />Skulle du f brug for en backslash ("\") eller et enkelt anfrselstegn ("\'") blandt disse vrdier, s tilfj en ekstra backslash (fx \'\\\\xyz\' or \'a\\\'b\').';
$strShow = 'Vis';
$strShowAll = 'Vis alt';
$strShowColor = 'Vis farve';
$strShowDatadictAs = 'Data Dictionary-format';
$strShowFullQueries = 'Vis fuldstndige foresprgsler';
$strShowGrid = 'Vis gitter';
$strShowPHPInfo = 'Vis PHP information';
$strShowTableDimension = 'Vis tabellernes dimensioner';
$strShowTables = 'Vis tabeller';
$strShowThisQuery = ' Vis foresprgslen her igen ';
$strShowingRecords = 'Viser poster ';
$strSimplifiedChinese = 'Simplificeret Kinesisk';
$strSingly = '(enkeltvis)';
$strSize = 'Strrelse';
$strSlovak = 'Slovakisk';
$strSlovenian = 'Slovensk';
$strSocketProblem = '(eller den lokale MySQL server\'s socket er ikke korrekt konfigureret)';
$strSort = 'Sorter';
$strSortByKey = 'Sorteringsngle';
$strSpaceUsage = 'Pladsforbrug';
$strSpanish = 'Spansk';
$strSplitWordsWithSpace = 'Ord adskilles af mellemrums-karakter (" ").';
$strStatCheckTime = 'Sidste check';
$strStatCreateTime = 'Oprettelse';
$strStatUpdateTime = 'Sidste opdatering';
$strStatement = 'Erklringer';
$strStatus = 'Status';
$strStorageEngine = 'Datalager';
$strStorageEngines = 'Datalagre';
$strStrucCSV = 'CSV-data';
$strStrucData = 'Struktur og data';
$strStrucDrop = 'Tilfj \'DROP TABLE\'';
$strStrucExcelCSV = 'CSV til MS Excel-data';
$strStrucNativeExcel = 'Fdte MS Excel-data';
$strStrucOnly = 'Kun strukturen';
$strStructPropose = 'Foresl tabelstruktur';
$strStructure = 'Struktur';
$strSubmit = 'Send';
$strSuccess = 'Din SQL-foresprgsel blev udfrt korrekt';
$strSum = 'Sum';
$strSwedish = 'Svensk';
$strSwitchToDatabase = 'Skift til den kopierede database';
$strSwitchToTable = 'Skift til den kopierede tabel';

$strTable = 'Tabel';
$strTableComments = 'Tabel kommentarer';
$strTableEmpty = 'Intet tabelnavn!';
$strTableHasBeenDropped = 'Tabel %s er slettet';
$strTableHasBeenEmptied = 'Tabel %s er tmt';
$strTableHasBeenFlushed = 'Tabel %s er blevet flushet';
$strTableMaintenance = 'Tabelvedligeholdelse';
$strTableOfContents = 'Indholdsfortegnelse';
$strTableOptions = 'Tabel-indstillinger';
$strTableStructure = 'Struktur-dump for tabellen';
$strTableType = 'Tabel type';
$strTables = '%s tabel(ler)';
$strTakeIt = 'tag det';
$strTblPrivileges = 'Tabel-specifikke privilegier';
$strTextAreaLength = ' P grund af feltets lngde,<br /> kan det muligvis ikke ndres ';
$strThai = 'Thai';
$strTheContent = 'Filens indhold er importeret.';
$strTheContents = 'Filens indhold erstatter indholdet af den valgte tabel for rkker med identisk primr eller unik ngle.';
$strTheTerminator = 'Felterne afgrnses af dette tegn.';
$strTheme = 'Tema / Layout';
$strThisHost = 'Denne Host';
$strThisNotDirectory = 'Dette var ikke en mappe';
$strThreadSuccessfullyKilled = 'Trd %s blev stoppet.';
$strTime = 'Tid';
$strToggleScratchboard = 'tegnebrt til/fra';
$strTotal = 'total';
$strTotalUC = 'Total';
$strTraditionalChinese = 'Traditionelt Kinesisk';
$strTraditionalSpanish = 'Traditionelt Spansk';
$strTraffic = 'Trafik';
$strTransformation_application_octetstream__download = 'Viser et link til at downloade et felts binre data. Frste mulighed er filnavnet p den binre fil. Anden mulighed er et muligt feltnavn fra en tabelrkke indeholdende filnavnet. Hvis du bruger anden mulighed, er feltet til den frste mulighed ndt til at vre sat til en tom streng.';
$strTransformation_application_octetstream__hex = 'Viser hexadecimal udgave af data.';
$strTransformation_image_jpeg__inline = 'Viser et klikbart minibilled; indstillinger: bredde,hjde i pixel (bevarer det originale perspektiv)';
$strTransformation_image_jpeg__link = 'Viser et link til dette billede (f.eks. direkte blob-download).';
$strTransformation_image_png__inline = 'Se image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Tager et TIME, TIMESTAMP eller DATETIME-felt og formatterer det til dit lokale datoformat. Frste parameter er offset (i timer) som lgges til tidsstemplet (Default: 0). Andte parameter er et andet datoformat ud fra PHPs strftime() definition.';
$strTransformation_text_plain__external = 'KUN LINUX: Starter en ekstern applikation og fder feltdata via standard input. Returnerer standardoutputtet for applikationen. Default er Tidy, for korrekt printet HTML-kode. Af sikkerhedsrsager er du ndt til manuelt at redigere filen libraries/transformations/text_plain__external.inc.php og indstte de vrktjer du vil tillade krsel af. Frste indstilling er s nummeret p det program du vil bruge og den anden indstilling er parametrene for det program. Tredie parameter, hvis sat til 1 vil konvertere outputtet vha. htmlspecialchars() (Default er 1). Et fjerde parameter, hvis sat til 1 vil stte et NOWRAP om cellens indhold s hele outputtet bliver vist uden omformattering (Default 1)';
$strTransformation_text_plain__formatted = 'Bevarer original formattering af feltet. Der laves ikke nogen Escaping.';
$strTransformation_text_plain__imagelink = 'Viser et billed og et link, feltet indeholder filnavnet; frste indstilling er et prfiks som "http://domain.com/", anden indstilling er bredde i pixel, tredie er hjden.';
$strTransformation_text_plain__link = 'Viser et link, feltet indeholder filnavnet; frste indstilling er et prfiks som "http://domain.com/", anden indstilling er en titel p linket.';
$strTransformation_text_plain__substr = 'Viser en del af en streng. Frste parameter er antal tegn der skal springes over fra begyndelsen af en streng (Standard 0). Andet parameter er antal tegn der returneres (Standard indtil enden af strengen). Det tredie parameter definerer hvilke karakterer der skal fjes til foran eller efter outputtet nr en substring (understreng) returneres (Standard: "...") .';
$strTruncateQueries = 'Trunkr viste foresprgsler';
$strTurkish = 'Tyrkisk';
$strType = 'Datatype';

$strUkrainian = 'Ukrainsk';
$strUncheckAll = 'Fjern alle mrker';
$strUnicode = 'Unicode';
$strUnique = 'Unik';
$strUnknown = 'ukendt';
$strUnselectAll = 'Fravlg alle';
$strUpdComTab = 'Se venligst Dokumentationen for oplysninger om hvordan du opdaterer din Column_comments (kolonne-kommentarer) tabel';
$strUpdatePrivMessage = 'Du har opdateret privilegierne for %s.';
$strUpdateProfileMessage = 'Profilen er blevet opdateret.';
$strUpdateQuery = 'Opdater foresprgsel';
$strUpgrade = 'Du burde opdatere til %s %s eller senere.';
$strUsage = 'Benyttelse';
$strUseBackquotes = 'Brug \'backquotes\' p tabellers og felters navne';
$strUseHostTable = 'Brug Host Tabel';
$strUseTabKey = 'Brug TAB tasten for at flytte dig fra vrdi til vrdi, eller CTRL+piletasterne til at flytte frit omkring';
$strUseTables = 'Benyt tabeller';
$strUseTextField = 'Brug tekstfelt';
$strUseThisValue = 'Brug denne vrdi';
$strUser = 'Bruger';
$strUserAlreadyExists = 'Brugeren %s findes i forvejen!';
$strUserEmpty = 'Intet brugernavn!';
$strUserName = 'Brugernavn';
$strUserNotFound = 'Den valgte bruger blev ikke fundet i privilegietabellen.';
$strUserOverview = 'Brugeroversigt';
$strUsersDeleted = 'De valgte brugere er blevet korrekt slettet.';
$strUsersHavingAccessToDb = 'Brugere med adgang til &quot;%s&quot;';

$strValidateSQL = 'Validr SQL';
$strValidatorError = 'SQL-validatoren kunne ikke initialiseres. Check venligst at du har de ndvendige php-udvidelser installeret som beskrevet i %sdokumentationen%s.';
$strValue = 'Vrdi';
$strVar = 'Variabel';
$strVersionInformation = 'Versionsinformation';
$strView = 'Visning';
$strViewDump = 'Vis dump (skema) over tabel';
$strViewDumpDB = 'Vis dump (skema) af database';
$strViewDumpDatabases = 'Vis dump (skema) for databaser';
$strViewHasBeenDropped = 'Visning %s er blevet droppet';

$strWebServerUploadDirectory = 'web-server upload mappe';
$strWebServerUploadDirectoryError = 'Mappen du har sat til upload-arbejde kan ikke findes';
$strWelcome = 'Velkommen til %s';
$strWestEuropean = 'Vesteuropisk';
$strWildcard = 'jokertegn';
$strWindowNotFound = 'Det angivne browservindue kunne ikke opdateres. Mske har du lukket det overliggende vindue eller din browser blokerer for tvr-vindue opdateringer i sikkerhedsindstillingerne';
$strWithChecked = 'Med det markerede:';
$strWriteRequests = 'Write-foresprgsler';
$strWritingCommentNotPossible = 'Skrivning af kommentar ikke muligt';
$strWritingRelationNotPossible = 'Skrivning af relation ikke muligt';
$strWrongUser = 'Forkert brugernavn/kodeord. Adgang ngtet.';

$strXML = 'XML';

$strYes = 'Ja';

$strZeroRemovesTheLimit = 'Bemrk: Indstilling af disse vrdier til 0 (nul) fjerner begrnsningen.';
$strZip = '"zippet"';

?>
